@@ -348,7 +348,7 @@ describe("generate_r_functions", {
 
     expect_equal(generate_r_functions(funs, package = "cpp11"),
 "foo <- function() {
-  invisible(.Call(\"_cpp11_foo\"))
+  invisible(.Call(`_cpp11_foo`))
 }")
   })
 
@@ -384,7 +384,7 @@ describe("generate_r_functions", {
 
     expect_equal(generate_r_functions(funs, package = "mypkg"),
 "foo <- function() {
-  invisible(.Call(\"_mypkg_foo\"))
+  invisible(.Call(`_mypkg_foo`))
 }")
   })
 
@@ -402,7 +402,7 @@ describe("generate_r_functions", {
 
     expect_equal(generate_r_functions(funs, package = "cpp11"),
 "foo <- function() {
-  .Call(\"_cpp11_foo\")
+  .Call(`_cpp11_foo`)
 }")
   })
 
@@ -438,7 +438,7 @@ describe("generate_r_functions", {
 
     expect_equal(generate_r_functions(funs, package = "cpp11"),
 "foo <- function(bar) {
-  invisible(.Call(\"_cpp11_foo\", bar))
+  invisible(.Call(`_cpp11_foo`, bar))
 }")
   })
 
@@ -456,7 +456,7 @@ describe("generate_r_functions", {
 
     expect_equal(generate_r_functions(funs, package = "cpp11"),
 "foo <- function(bar) {
-  .Call(\"_cpp11_foo\", bar)
+  .Call(`_cpp11_foo`, bar)
 }")
   })
 
@@ -477,11 +477,11 @@ describe("generate_r_functions", {
 
     expect_equal(generate_r_functions(funs, package = "cpp11"),
 "foo <- function(bar) {
-  .Call(\"_cpp11_foo\", bar)
+  .Call(`_cpp11_foo`, bar)
 }
 
 bar <- function(baz) {
-  .Call(\"_cpp11_bar\", baz)
+  .Call(`_cpp11_bar`, baz)
 }")
   })
 })
@@ -512,7 +512,7 @@ describe("cpp_register", {
 "# Generated by cpp11: do not edit by hand
 
 foo <- function() {
-  .Call(\"_testPkg_foo\", PACKAGE = \"testPkg\")
+  .Call(`_testPkg_foo`)
 }
 ")
     cpp_bindings <- file.path(p, "src", "cpp11.cpp")
@@ -545,6 +545,7 @@ static const R_CallMethodDef CallEntries[] = {
 extern \"C\" void R_init_testPkg(DllInfo* dll){
   R_registerRoutines(dll, NULL, CallEntries, NULL, NULL);
   R_useDynamicSymbols(dll, FALSE);
+  R_forceSymbols(dll, TRUE);
 }
 ")
   })
@@ -702,3 +703,36 @@ describe("generate_init_functions", {
     expect_equal(generate_init_functions(funs), list(declarations = "\nvoid foo(DllInfo* dll);\nvoid bar(DllInfo* dll);\n", calls = "\n  foo(dll);\n  bar(dll);"))
   })
 })
+
+test_that("check_valid_attributes does not return an error if all registers are correct", {
+  pkg <- local_package()
+  p <- pkg_path(pkg)
+  dir.create(file.path(p, "src"))
+  file.copy(test_path("single.cpp"), file.path(p, "src", "single.cpp"))
+
+  expect_error_free(cpp_register(p))
+
+  pkg <- local_package()
+  p <- pkg_path(pkg)
+  dir.create(file.path(p, "src"))
+  file.copy(test_path("multiple.cpp"), file.path(p, "src", "multiple.cpp"))
+
+  expect_error_free(cpp_register(p))
+})
+
+
+test_that("check_valid_attributes returns an error if one or more registers is incorrect", {
+  pkg <- local_package()
+  p <- pkg_path(pkg)
+  dir.create(file.path(p, "src"))
+  file.copy(test_path("single_incorrect.cpp"), file.path(p, "src", "single_incorrect.cpp"))
+
+  expect_error(cpp_register(p))
+
+  pkg <- local_package()
+  p <- pkg_path(pkg)
+  dir.create(file.path(p, "src"))
+  file.copy(test_path("multiple_incorrect.cpp"), file.path(p, "src", "multiple_incorrect.cpp"))
+
+  expect_error(cpp_register(p))
+})
